# Concepts

These pages explain Monkay’s core abstractions and execution flow.

- [Module lifecycle](module-lifecycle.md)
- [Settings and extensions](settings-and-extensions.md)
- [Context cages](context-cages.md)
